@@ -67,6 +67,8 @@ pub use dir::{Dir, Entry, SeekLoc};
     target_os = "redox"
 )))]
 pub use fadvise::{fadvise, Advice};
+#[cfg(not(target_os = "wasi"))]
+pub use fcntl::fcntl_dupfd_cloexec;
 #[cfg(not(any(
     target_os = "freebsd",
     target_os = "ios",
@@ -85,12 +87,14 @@ pub use fcopyfile::{
 };
 #[cfg(not(target_os = "wasi"))]
 pub use fd::fchmod;
+#[cfg(not(any(target_os = "macos", target_os = "ios", target_os = "redox")))]
+pub use fd::fdatasync;
 #[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "wasi")))]
 // not implemented in libc for netbsd yet
 pub use fd::fstatfs;
 #[cfg(not(any(target_os = "netbsd", target_os = "redox", target_os = "openbsd")))]
 pub use fd::posix_fallocate;
-pub use fd::{futimens, is_file_read_write, seek, tell};
+pub use fd::{fstat, fsync, ftruncate, futimens, is_file_read_write, seek, tell};
 pub use file_type::FileType;
 #[cfg(any(target_os = "macos", target_os = "ios"))]
 pub use getpath::getpath;
