@@ -8,8 +8,6 @@ mod poll;
 #[cfg(any(target_os = "macos", target_os = "ios"))]
 mod rdadvise;
 mod read_write;
-#[cfg(not(target_os = "wasi"))]
-mod socketpair;
 #[cfg(any(target_os = "android", target_os = "linux"))]
 mod userfaultfd;
 
@@ -39,8 +37,6 @@ pub use read_write::{pread, pwrite, read, readv, write, writev};
 pub use read_write::{preadv, pwritev};
 #[cfg(any(linux_raw, all(libc, target_os = "linux", target_env = "gnu")))]
 pub use read_write::{preadv2, pwritev2};
-#[cfg(not(target_os = "wasi"))]
-pub use socketpair::socketpair_stream;
 #[cfg(any(target_os = "android", target_os = "linux"))]
 pub use userfaultfd::{userfaultfd, UserFaultFdFlags};
 
