@@ -1,21 +1,20 @@
-//! `posish` provides safe wrappers to `libc` functions. The current focus is
-//! on the functionality needed by [`cap-std`] and [`system-interface`] that
-//! isn't provided by [`std`] or [`getrandom`].
+//! `posish` provides efficient memory-safe and [I/O-safe] wrappers to
+//! "POSIX-ish" `libc` APIs and syscalls.
 //!
 //! The wrappers perform the following tasks:
-//!  - Error values are translated to `Result`s.
-//!  - Out-parameters are translated to return values.
-//!  - Path arguments can by any kind of string type.
-//!  - File descriptors are passed in through arguments implementing [`AsFd`]
-//!    instead of as bare integers and returned as [`OwnedFd`]s.
+//!  - Error values are translated to [`Result`]s.
+//!  - Buffers are passed as Rust slices.
+//!  - Out-parameters are presented as return values.
+//!  - Path arguments use `AsRef<`[`Arg`]`>`, so they accept any string type.
+//!  - File descriptors are passed and returned via [`AsFd`] and [`OwnedFd`]
+//!    instead of bare integers, ensuring I/O safety.
 //!  - Constants use `enum`s and [`bitflags`] types.
 //!  - Multiplexed functions (eg. `fcntl`, `ioctl`, etc.) are de-multiplexed.
 //!  - Variadic functions (eg. `openat`, etc.) are presented as non-variadic.
-//!  - Functions and types which need `64` suffixes to enable large-file
-//!    support are used automatically.
+//!  - Functions and types which need `l` prefixes or `64` suffixes to enable
+//!    large-file support are used automatically, and file sizes and offsets
+//!    are presented as `i64` and `u64`.
 //!  - Behaviors that depend on the sizes of C types like `long` are hidden.
-//!  - File offsets and sizes are presented as `i64` and `u64` rather than
-//!    `off_t`.
 //!  - In some places, more human-friendly and less historical-accident names
 //!    are used.
 //!
@@ -30,11 +29,6 @@
 //! which do hide significant differences between platforms, and [`cap-std`]
 //! which does perform sandboxing and restricts ambient authorities.
 //!
-//! # Safety
-//!
-//! This library uses the [io-lifetimes crate] to manage all OS resource
-//! handles, automatically ensuring I/O safety.
-//!
 //! [`cap-std`]: https://crates.io/crates/cap-std
 //! [`system-interface`]: https://crates.io/crates/system-interface
 //! [`io-streams`]: https://crates.io/crates/io-streams
@@ -45,11 +39,18 @@
 //! [`AsFd`]: https://docs.rs/io-lifetimes/latest/io_lifetimes/trait.AsFd.html
 //! [`OwnedFd`]: https://docs.rs/io-lifetimes/latest/io_lifetimes/struct.OwnedFd.html
 //! [io-lifetimes crate]: https://crates.io/crates/io-lifetimes
+//! [I/O-safe]: https://github.com/rust-lang/rfcs/pull/3128
+//! [`Result`]: https://docs.rs/posish/latest/posish/io/type.Result.html
+//! [`Arg`]: https://docs.rs/posish/latest/posish/path/trait.Arg.html
 
 #![deny(missing_docs)]
 #![cfg_attr(linux_raw, feature(asm))]
 #![cfg_attr(target_os = "wasi", feature(wasi_ext))]
 
+/// Re-export `io_lifetimes` since we use its types in our public API, so
+/// that our users don't need to do anything special to use the same version.
+pub use io_lifetimes;
+
 #[cfg(all(libc, not(target_os = "wasi")))]
 #[macro_use]
 mod weak;
@@ -127,3 +128,17 @@ macro_rules! is_impls {
 
 #[cfg(libc)]
 is_impls! { i32 i64 isize }
+
+/// Convert a `&T` into a `*const T` without using an `as`.
+#[inline]
+#[allow(dead_code)]
+const fn as_ptr<T>(t: &T) -> *const T {
+    t
+}
+
+/// Convert a `&mut T` into a `*mut T` without using an `as`.
+#[inline]
+#[allow(dead_code)]
+fn as_mut_ptr<T>(t: &mut T) -> *mut T {
+    t
+}
